bayespy.nodes.GaussianMarkovChain
=================================

.. currentmodule:: bayespy.nodes

.. autoclass:: GaussianMarkovChain

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: generated/
   
      ~GaussianMarkovChain.__init__
      ~GaussianMarkovChain.add_plate_axis
      ~GaussianMarkovChain.broadcasting_multiplier
      ~GaussianMarkovChain.delete
      ~GaussianMarkovChain.get_gradient
      ~GaussianMarkovChain.get_mask
      ~GaussianMarkovChain.get_moments
      ~GaussianMarkovChain.get_parameters
      ~GaussianMarkovChain.get_riemannian_gradient
      ~GaussianMarkovChain.get_shape
      ~GaussianMarkovChain.has_plotter
      ~GaussianMarkovChain.initialize_from_parameters
      ~GaussianMarkovChain.initialize_from_prior
      ~GaussianMarkovChain.initialize_from_random
      ~GaussianMarkovChain.initialize_from_value
      ~GaussianMarkovChain.load
      ~GaussianMarkovChain.logpdf
      ~GaussianMarkovChain.lower_bound_contribution
      ~GaussianMarkovChain.lowerbound
      ~GaussianMarkovChain.move_plates
      ~GaussianMarkovChain.observe
      ~GaussianMarkovChain.pdf
      ~GaussianMarkovChain.plot
      ~GaussianMarkovChain.random
      ~GaussianMarkovChain.rotate
      ~GaussianMarkovChain.save
      ~GaussianMarkovChain.set_parameters
      ~GaussianMarkovChain.set_plotter
      ~GaussianMarkovChain.show
      ~GaussianMarkovChain.unobserve
      ~GaussianMarkovChain.update
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
      :toctree: generated/
   
      ~GaussianMarkovChain.dims
      ~GaussianMarkovChain.plates
      ~GaussianMarkovChain.plates_multiplier
   
   